@@ -33,14 +33,12 @@ class AppChooserDialog : public QDialog
 {
     Q_OBJECT
 public:
-    AppChooserDialog(const QStringList &choices, QDialog* parent = 0, Qt::WindowFlags flags = 0);
+    AppChooserDialog(const QStringList &choices, QDialog *parent = nullptr, Qt::WindowFlags flags = 0);
     ~AppChooserDialog();
 
     QString selectedApplication() const;
     void setSelectedApplication(const QString &applicationName);
 
-    void setLabelText(const QString &label);
-
 public Q_SLOTS:
     void searchTextChanged(const QString &text);
 
